@@ -311,7 +311,7 @@ static void on_response(GtkDialog* dlg, int response, FmFilePropData* data)
 
         /* check if chmod is needed here. */
         sel = gtk_combo_box_get_active(data->read_perm);
-        if( sel != NO_CHANGE ) /* requested to change read permissions */
+        if( sel > NO_CHANGE ) /* requested to change read permissions */
         {
             g_debug("got selection for read: %d", sel);
             if(data->read_perm_sel != sel) /* new value is different from original */
@@ -336,7 +336,7 @@ static void on_response(GtkDialog* dlg, int response, FmFilePropData* data)
             data->read_perm_sel = NO_CHANGE;
 
         sel = gtk_combo_box_get_active(data->write_perm);
-        if( sel != NO_CHANGE ) /* requested to change write permissions */
+        if( sel > NO_CHANGE ) /* requested to change write permissions */
         {
             g_debug("got selection for write: %d", sel);
             if(data->write_perm_sel != sel) /* new value is different from original */
@@ -361,7 +361,7 @@ static void on_response(GtkDialog* dlg, int response, FmFilePropData* data)
             data->write_perm_sel = NO_CHANGE;
 
         sel = gtk_combo_box_get_active(data->exec_perm);
-        if( sel != NO_CHANGE ) /* requested to change exec permissions */
+        if( sel > NO_CHANGE ) /* requested to change exec permissions */
         {
             g_debug("got selection for exec: %d", sel);
             if(data->exec_perm_sel != sel) /* new value is different from original */
@@ -391,7 +391,7 @@ static void on_response(GtkDialog* dlg, int response, FmFilePropData* data)
             sel = gtk_combo_box_get_active(data->flags_set_file);
         else
             sel = NO_CHANGE;
-        if( sel != NO_CHANGE ) /* requested to change special bits */
+        if( sel > NO_CHANGE ) /* requested to change special bits */
         {
             g_debug("got selection for flags: %d", sel);
             if(data->flags_set_sel != sel) /* new value is different from original */
@@ -591,8 +591,8 @@ static void update_permissions(FmFilePropData* data)
     /* on local filesystems, only root can do chown. */
     if( data->all_native && geteuid() != 0 )
     {
-        gtk_editable_set_editable(GTK_EDITABLE(data->owner), FALSE);
-        gtk_editable_set_editable(GTK_EDITABLE(data->group), FALSE);
+        gtk_widget_set_sensitive(GTK_WIDGET(data->owner), FALSE);
+        gtk_widget_set_sensitive(GTK_WIDGET(data->group), FALSE);
     }
 
     /* read access chooser */
@@ -772,9 +772,16 @@ static void update_ui(FmFilePropData* data)
         time_t atime;
         struct tm tm;
         gtk_entry_set_text(data->name, fm_file_info_get_disp_name(data->fi));
+        /* FIXME: check if text fits in line */
+        if(strlen(fm_file_info_get_disp_name(data->fi)) > 16)
+            gtk_widget_set_tooltip_text(GTK_WIDGET(data->name),
+                                        fm_file_info_get_disp_name(data->fi));
         if(parent_str)
         {
             gtk_label_set_text(data->dir, parent_str);
+            /* FIXME: check if text fits in line */
+            if(strlen(parent_str) > 16)
+                gtk_widget_set_tooltip_text(GTK_WIDGET(data->dir), parent_str);
             g_free(parent_str);
         }
         else
@@ -786,6 +793,9 @@ static void update_ui(FmFilePropData* data)
         localtime_r(&atime, &tm);
         strftime(buf, sizeof(buf), "%x %R", &tm);
         gtk_label_set_text(data->atime, buf);
+        /* FIXME: changing file name isn't implemented yet, disable entry */
+        gtk_widget_set_can_focus(GTK_WIDGET(data->name), FALSE);
+        gtk_editable_set_editable(GTK_EDITABLE(data->name), FALSE);
     }
     else
     {
