@@ -172,9 +172,9 @@ static const GtkActionEntry folder_popup_actions[]=
     {"NewShortcut", "system-run", N_("Shortcut"), NULL, NULL, G_CALLBACK(on_create_new)},
     {"Cut", GTK_STOCK_CUT, NULL, "<Ctrl>X", NULL, G_CALLBACK(on_cut)},
     {"Copy", GTK_STOCK_COPY, NULL, "<Ctrl>C", NULL, G_CALLBACK(on_copy)},
-    {"Copy2", NULL, NULL, "<Shift>Insert", NULL, G_CALLBACK(on_copy)},
+    {"Copy2", NULL, NULL, "<Ctrl>Insert", NULL, G_CALLBACK(on_copy)},
     {"Paste", GTK_STOCK_PASTE, NULL, "<Ctrl>V", NULL, G_CALLBACK(on_paste)},
-    {"Paste2", NULL, NULL, "<Ctrl>Insert", NULL, G_CALLBACK(on_paste)},
+    {"Paste2", NULL, NULL, "<Shift>Insert", NULL, G_CALLBACK(on_paste)},
     {"Del", GTK_STOCK_DELETE, NULL, "Delete", NULL, G_CALLBACK(on_trash)},
     {"Del2", NULL, NULL, "KP_Delete", NULL, G_CALLBACK(on_trash)},
     {"Remove", GTK_STOCK_REMOVE, NULL, "<Shift>Delete", NULL, G_CALLBACK(on_rm)},
@@ -624,6 +624,9 @@ void fm_folder_view_set_model(FmFolderView* fv, FmFolderModel* model)
     {
         fm_folder_model_get_sort(old_model, &by, &mode);
         unset_model(fv, old_model);
+        /* https://bugs.launchpad.net/ubuntu/+source/pcmanfm/+bug/1071231:
+           after changing the folder selection isn't reset */
+        iface->unselect_all(fv);
     }
     /* FIXME: which setting to apply if this is first model? */
     iface->set_model(fv, model);
@@ -1001,7 +1004,15 @@ static void on_trash(GtkAction* act, FmFolderView* fv)
         }
     }
     else if(GTK_IS_EDITABLE(focus)) /* fallback for editables */
+    {
+        if(!gtk_editable_get_selection_bounds((GtkEditable*)focus, NULL, NULL))
+        {
+            gint pos = gtk_editable_get_position((GtkEditable*)focus);
+            /* if no text selected then delete character next to cursor */
+            gtk_editable_select_region((GtkEditable*)focus, pos, pos + 1);
+        }
         gtk_editable_delete_selection((GtkEditable*)focus);
+    }
 }
 
 static void on_rm(GtkAction* act, FmFolderView* fv)
@@ -1027,7 +1038,15 @@ static void on_rm(GtkAction* act, FmFolderView* fv)
 
 static void on_select_all(GtkAction* act, FmFolderView* fv)
 {
-    fm_folder_view_select_all(fv);
+    GtkMenu *popup = g_object_get_qdata(G_OBJECT(fv), popup_quark);
+    GtkWidget *win = gtk_menu_get_attach_widget(popup);
+    GtkWidget *focus = gtk_window_get_focus(GTK_WINDOW(win));
+
+    /* check if we are inside the view; for desktop focus will be NULL */
+    if(focus == NULL || gtk_widget_is_ancestor(focus, GTK_WIDGET(fv)))
+        fm_folder_view_select_all(fv);
+    else if(GTK_IS_EDITABLE(focus)) /* fallback for editables */
+        gtk_editable_select_region((GtkEditable*)focus, 0, -1);
 }
 
 static void on_invert_select(GtkAction* act, FmFolderView* fv)
@@ -1172,8 +1191,10 @@ static void on_ui_destroy(gpointer ui_ptr)
     GtkMenu* popup = GTK_MENU(gtk_ui_manager_get_widget(ui, "/popup"));
     GtkWindow* win = GTK_WINDOW(gtk_menu_get_attach_widget(popup));
     GtkAccelGroup* accel_grp = gtk_ui_manager_get_accel_group(ui);
+    GSList *groups;
 
-    if(!gtk_accel_group_get_is_locked(accel_grp))
+    groups = gtk_accel_groups_from_object(G_OBJECT(win));
+    if(g_slist_find(groups, accel_grp) != NULL)
         gtk_window_remove_accel_group(win, accel_grp);
     gtk_widget_destroy(GTK_WIDGET(popup));
     g_object_unref(ui);
@@ -1325,7 +1346,8 @@ void fm_folder_view_set_active(FmFolderView* fv, gboolean set)
     GtkMenu *popup;
     GtkWindow* win;
     GtkAccelGroup* accel_grp;
-    gboolean locked;
+    GSList *groups;
+    gboolean active;
 
     g_return_if_fail(FM_IS_FOLDER_VIEW(fv));
 
@@ -1337,18 +1359,13 @@ void fm_folder_view_set_active(FmFolderView* fv, gboolean set)
 
     win = GTK_WINDOW(gtk_menu_get_attach_widget(popup));
     accel_grp = gtk_ui_manager_get_accel_group(ui);
-    locked = gtk_accel_group_get_is_locked(accel_grp);
+    groups = gtk_accel_groups_from_object(G_OBJECT(win));
+    active = (g_slist_find(groups, accel_grp) != NULL);
 
-    if(set && locked)
-    {
+    if(set && !active)
         gtk_window_add_accel_group(win, accel_grp);
-        gtk_accel_group_unlock(accel_grp);
-    }
-    else if(!set && !locked)
-    {
+    else if(!set && active)
         gtk_window_remove_accel_group(win, accel_grp);
-        gtk_accel_group_lock(accel_grp);
-    }
 }
 
 /**
