@@ -25,12 +25,8 @@
 
 #include <gtk/gtk.h>
 #include "fm-file-info.h"
-#include "fm-path.h"
-#include "fm-dnd-src.h"
-#include "fm-dnd-dest.h"
-#include "fm-folder.h"
 #include "fm-folder-model.h"
-#include "fm-file-menu.h"
+#include "fm-file-launcher.h"
 
 G_BEGIN_DECLS
 
@@ -89,8 +85,8 @@ typedef void (*FmFolderViewUpdatePopup)(FmFolderView* fv, GtkWindow* window,
  * @sort_changed: the class closure for #FmFolderView::sort-changed signal
  * @set_sel_mode: VTable func, see fm_folder_view_set_selection_mode()
  * @get_sel_mode: VTable func, see fm_folder_view_get_selection_mode()
- * @set_sort: function to save sorting mode in the object structure
- * @get_sort: function to retrieve sort sorting mode from the object structure
+ * @set_sort: unused since 1.0.2, will be removed from ABI 5
+ * @get_sort: unused since 1.0.2, will be removed from ABI 5
  * @set_show_hidden: function to save show_hidden in the object structure
  * @get_show_hidden: function to retrieve show_hidden from the object structure
  * @get_folder: VTable func, see fm_folder_view_get_folder()
@@ -105,6 +101,9 @@ typedef void (*FmFolderViewUpdatePopup)(FmFolderView* fv, GtkWindow* window,
  * @select_file_path: VTable func, see fm_folder_view_select_file_path()
  * @get_custom_menu_callbacks: function to retrieve callbacks for popup menu setup
  */
+/* FIXME: after ABI change:
+ * @filter_changed: (since 1.0.2) the class closure for #FmFolderView::filter-changed signal
+ */
 struct _FmFolderViewInterface
 {
     /*< private >*/
@@ -115,14 +114,15 @@ struct _FmFolderViewInterface
     void (*clicked)(FmFolderView* fv, FmFolderViewClickType type, FmFileInfo* file);
     void (*sel_changed)(FmFolderView* fv, FmFileInfoList* sels);
     void (*sort_changed)(FmFolderView* fv);
+    /* void (*filter_changed)(FmFolderView* fv); */
     //void (*chdir)(FmFolderView* fv, FmPath* path);
 
     /* VTable */
     void (*set_sel_mode)(FmFolderView* fv, GtkSelectionMode mode);
     GtkSelectionMode (*get_sel_mode)(FmFolderView* fv);
 
-    void (*set_sort)(FmFolderView* fv, GtkSortType type, FmFolderModelViewCol by);
-    void (*get_sort)(FmFolderView* fv, GtkSortType* type, FmFolderModelViewCol* by);
+    void (*set_sort)(FmFolderView* fv, GtkSortType type, FmFolderModelCol by);
+    void (*get_sort)(FmFolderView* fv, GtkSortType* type, FmFolderModelCol* by);
 
     void (*set_show_hidden)(FmFolderView* fv, gboolean show);
     gboolean (*get_show_hidden)(FmFolderView* fv);
@@ -144,6 +144,7 @@ struct _FmFolderViewInterface
     /* for implementation internal usage */
     void (*get_custom_menu_callbacks)(FmFolderView* fv, FmFolderViewUpdatePopup*,
                                       FmLaunchFolderFunc*);
+    /* FIXME: add few reserved after ABI change */
 };
 
 GType           fm_folder_view_get_type(void);
@@ -152,10 +153,6 @@ GType           fm_folder_view_get_type(void);
 void            fm_folder_view_set_selection_mode(FmFolderView* fv, GtkSelectionMode mode);
 GtkSelectionMode fm_folder_view_get_selection_mode(FmFolderView* fv);
 
-void            fm_folder_view_sort(FmFolderView* fv, GtkSortType type, FmFolderModelViewCol by);
-GtkSortType     fm_folder_view_get_sort_type(FmFolderView* fv);
-FmFolderModelViewCol fm_folder_view_get_sort_by(FmFolderView* fv);
-
 void            fm_folder_view_set_show_hidden(FmFolderView* fv, gboolean show);
 gboolean        fm_folder_view_get_show_hidden(FmFolderView* fv);
 
@@ -192,6 +189,11 @@ void            fm_folder_view_sel_changed(GObject* obj, FmFolderView* fv);
 //void            fm_folder_view_chdir(FmFolderView* fv, FmPath* path);
 
 #ifndef FM_DISABLE_DEPRECATED
+/* deprecated since 1.0.2; left until soname 5 for compatibility */
+void            fm_folder_view_sort(FmFolderView* fv, GtkSortType type, FmFolderModelCol by);
+GtkSortType     fm_folder_view_get_sort_type(FmFolderView* fv);
+FmFolderModelCol fm_folder_view_get_sort_by(FmFolderView* fv);
+
 /* functions defined in fm-standard-view.c
  * are obsoleted since 1.0.1 but left until soname 5 for compatibility */
 FmFolderView* fm_folder_view_new(guint mode);
@@ -202,6 +204,29 @@ guint fm_folder_view_get_mode(FmFolderView* fv);
 void fm_folder_view_select_custom(FmFolderView* fv, GFunc filter, gpointer user_data);
 #endif
 
+typedef struct _FmFolderViewColumnInfo FmFolderViewColumnInfo;
+
+/**
+ * FmFolderViewColumnInfo:
+ * @col_id: column type
+ *
+ * FmFolderView column setup data.
+ */
+struct _FmFolderViewColumnInfo
+{
+    /*< public >*/
+    FmFolderModelCol col_id;
+
+    /*< private >*/
+    gint reserved1; /* reserved members for usage by interface implementations */
+    gint reserved2;
+    gint reserved3;
+    gint reserved4;
+};
+
+gboolean        fm_folder_view_set_columns(FmFolderView* fv, const GSList* cols);
+GSList*         fm_folder_view_get_columns(FmFolderView* fv);
+
 G_END_DECLS
 
 #endif /* __FOLDER_VIEW_H__ */
