@@ -15,6 +15,14 @@ extern void fm_marshal_BOOLEAN__INT_INT_UINT_UINT_POINTER (GClosure     *closure
                                                            gpointer      marshal_data);
 #define fm_marshal_BOOL__INT_INT_UINT_UINT_POINTER	fm_marshal_BOOLEAN__INT_INT_UINT_UINT_POINTER
 
+/* VOID:BOXED,BOXED,POINTER (gtk/fm-gtk-marshal.list:2) */
+extern void fm_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
+                                                  GValue       *return_value,
+                                                  guint         n_param_values,
+                                                  const GValue *param_values,
+                                                  gpointer      invocation_hint,
+                                                  gpointer      marshal_data);
+
 G_END_DECLS
 
 #endif /* __fm_marshal_MARSHAL_H__ */
