@@ -1,18 +1,18 @@
 /*
  *      fm-file-ops-job-delete.h
- *      
+ *
  *      Copyright 2009 Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
- *      
+ *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
  *      the Free Software Foundation; either version 2 of the License, or
  *      (at your option) any later version.
- *      
+ *
  *      This program is distributed in the hope that it will be useful,
  *      but WITHOUT ANY WARRANTY; without even the implied warranty of
  *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *      GNU General Public License for more details.
- *      
+ *
  *      You should have received a copy of the GNU General Public License
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
@@ -28,11 +28,14 @@
 
 G_BEGIN_DECLS
 
-gboolean fm_file_ops_job_delete_file(FmJob* job, GFile* gf, GFileInfo* inf);
-gboolean fm_file_ops_job_delete_run(FmFileOpsJob* job);
+gboolean _fm_file_ops_job_delete_file(FmJob* job, GFile* gf, GFileInfo* inf);
+gboolean _fm_file_ops_job_delete_run(FmFileOpsJob* job);
 
-gboolean fm_file_ops_job_trash_file(FmJob* job, GFile* gf, GFileInfo* inf);
-gboolean fm_file_ops_job_trash_run(FmFileOpsJob* job);
+/* gboolean _fm_file_ops_job_trash_file(FmJob* job, GFile* gf, GFileInfo* inf); */
+gboolean _fm_file_ops_job_trash_run(FmFileOpsJob* job);
+
+/* gboolean _fm_file_ops_job_untrash_file(FmJob* job, GFile* gf, GFileInfo* inf); */
+gboolean _fm_file_ops_job_untrash_run(FmFileOpsJob* job);
 
 G_END_DECLS
 
